@@ -1,6 +1,6 @@
 import logging
 from pathlib import Path
-from typing import List
+from typing import List, Optional
 
 import bokeh
 import bokeh.layouts
@@ -11,6 +11,8 @@ from bokeh.core.properties import Color
 from bokeh.models import HoverTool
 from bokeh.plotting import ColumnDataSource, figure
 
+from annofabcli.common.utils import _catch_exception
+
 logger = logging.getLogger(__name__)
 
 
@@ -35,10 +37,9 @@ class Scatter:
     # Private
     #############################################
 
-    def __init__(self, outdir: str, project_id: str):
-        self.outdir = outdir
-        self.scatter_outdir = f"{outdir}/scatter"
-        self.short_project_id = project_id[0:8]
+    def __init__(self, outdir: str, filename_prefix: Optional[str] = None):
+        self.scatter_outdir = outdir
+        self.filename_prefix = filename_prefix + "-" if filename_prefix is not None else ""
         Path(self.scatter_outdir).mkdir(exist_ok=True, parents=True)
 
     @staticmethod
@@ -114,6 +115,7 @@ class Scatter:
             phase_list.remove(TaskPhase.ACCEPTANCE.value)
         return phase_list
 
+    @_catch_exception
     def write_scatter_for_productivity_by_monitored_worktime(self, df: pandas.DataFrame):
         """
         AnnoFab計測時間を元に算出した生産性を、メンバごとにプロットする
@@ -136,7 +138,7 @@ class Scatter:
             )
 
         html_title = "散布図-アノテーションあたり作業時間と累計作業時間の関係-計測時間"
-        output_file = f"{self.scatter_outdir}/{self.short_project_id}-{html_title}.html"
+        output_file = f"{self.scatter_outdir}/{self.filename_prefix}{html_title}.html"
         logger.debug(f"{output_file} を出力します。")
 
         phase_list = self._get_phase_list(df)
@@ -183,6 +185,7 @@ class Scatter:
         bokeh.plotting.output_file(output_file, title=html_title)
         bokeh.plotting.save(bokeh.layouts.column(figure_list))
 
+    @_catch_exception
     def write_scatter_for_productivity_by_actual_worktime(self, df: pandas.DataFrame):
         """
         実績作業時間を元に算出した生産性を、メンバごとにプロットする
@@ -203,7 +206,7 @@ class Scatter:
             )
 
         html_title = "散布図-アノテーションあたり作業時間と累計作業時間の関係-実績時間"
-        output_file = f"{self.scatter_outdir}/{self.short_project_id}-{html_title}.html"
+        output_file = f"{self.scatter_outdir}/{self.filename_prefix}{html_title}.html"
         logger.debug(f"{output_file} を出力します。")
 
         phase_list = self._get_phase_list(df)
@@ -250,6 +253,7 @@ class Scatter:
         bokeh.plotting.output_file(output_file, title=html_title)
         bokeh.plotting.save(bokeh.layouts.column(figure_list))
 
+    @_catch_exception
     def write_scatter_for_quality(self, df: pandas.DataFrame):
         """
         メンバごとに品質を散布図でプロットする
@@ -266,7 +270,7 @@ class Scatter:
             )
 
         html_title = "散布図-教師付者の品質と作業量の関係"
-        output_file = f"{self.scatter_outdir}/{self.short_project_id}-{html_title}.html"
+        output_file = f"{self.scatter_outdir}/{self.filename_prefix}{html_title}.html"
         logger.debug(f"{output_file} を出力します。")
 
         figure_list = [
