@@ -60,10 +60,11 @@ class WriteCsvGraph:
 
     def __init__(self, table_obj: Table, output_dir: Path, project_id: str):
         self.table_obj = table_obj
-        self.csv_obj = Csv(str(output_dir), project_id)
-        self.histogram_obj = Histogram(str(output_dir / "histogram"), project_id)
-        self.graph_obj = LineGraph(str(output_dir / "line-graph"), project_id)
-        self.scatter_obj = Scatter(str(output_dir / "scatter"), project_id)
+        filename_prefix = project_id[0:8]
+        self.csv_obj = Csv(str(output_dir), filename_prefix=filename_prefix)
+        self.histogram_obj = Histogram(str(output_dir / "histogram"), filename_prefix)
+        self.graph_obj = LineGraph(str(output_dir / "line-graph"), filename_prefix)
+        self.scatter_obj = Scatter(str(output_dir / "scatter"), filename_prefix)
 
     def _get_task_df(self):
         if self.task_df is None:
@@ -316,12 +317,15 @@ class VisualizeStatistics(AbstractCommandLineInterface):
             database.update_db(download_latest)
 
         table_obj = Table(database, ignored_task_id_list)
-        write_project_name_file(self.service, project_id, output_dir)
-
-        write_obj = WriteCsvGraph(table_obj, output_dir, project_id)
-        if len(write_obj._get_task_df()) == 0:
+        if len(table_obj._get_task_list()) == 0:
             logger.warning(f"タスク一覧が0件なのでファイルを出力しません。終了します。")
             return
+        if len(table_obj._get_task_histories_dict().keys()) == 0:
+            logger.warning(f"タスク履歴一覧が0件なのでファイルを出力しません。終了します。")
+            return
+
+        write_project_name_file(self.service, project_id, output_dir)
+        write_obj = WriteCsvGraph(table_obj, output_dir, project_id)
         write_obj.write_csv_for_task()
 
         # ヒストグラム
